import React, { Component } from "react";
import style from "./index.less";
import classNames from 'classnames';
/***
 * 标签组件
 * author:zn@2018-11-08
 * 接收参数：
 * prefix：前缀文字
 * value:输入的值
 * placeholder
 * suffix：后缀文字
 *
 ***/
class InlineTag extends Component {
  constructor(props){
    super(props);
    this.$span = React.createRef();
    this.state = {
      value:props.value||'',
      placeholder:props.placeholder||''
    };
    this.handleBlur = this.handleBlur.bind(this);
    this.handleInput = this.handleInput.bind(this);
    this.handleFocus = this.handleFocus.bind(this);
    this.handleFixClick = this.handleFixClick.bind(this);
  }
  handleInput(e){       //输入时保存临时值，在修改灰显为黑色时判断用
    e.stopPropagation();
    const value = e.target.innerText||e.target.innerHTML.replace(/&nbsp;$|^&nbsp;/,'');//兼容firefox26
    this.setState({
      value:value
    })
  }
  handleBlur(e){         //鼠标离开是保存值到store中
    e.stopPropagation(); //不阻止会触发外层div的失焦事件
    const value = e.target.innerText||e.target.innerHTML.replace(/&nbsp;$|^&nbsp;/,'');;
    const {handleInput,ikey,prefix,suffix,placeholder} = this.props;
    if(!value.trim()){
      this.setState({
        placeholder:placeholder,
        value:''
      });
    }
    //this.$span.current.innerText?(this.$span.current.innerText=''):(this.$span.current.innerHTML='');      //修改生成文字变成输入的2倍bug
    handleInput&&handleInput({text:value.trim(),ikey,prefix,suffix});
    this.setState({
      value:value.trim()
    });
  }
  handleFocus(e){
    e.stopPropagation();
    const text = e.target.innerText || e.target.innerHTML.replace(/&nbsp;$|^&nbsp;/,'');;
    const {placeholder} = this.props;
    if(text.trim()==placeholder){
      this.setState({
        placeholder:''
      });
    }
  }
  getStyle(){
    const {hideTag,placeholder} = this.props;
    const value = this.state.value;//this.$span.current&&this.$span.current.innerText.trim();
    if(hideTag){
      if(value){
        return classNames(style['selected-no-tag']);
      }
      return style['no-tag'];
    }
    if(!value||value.trim()==placeholder){
      return classNames(style['gray']);
    }
    return style['selected-tag'];
  }
  moveEnd(obj) {
    if(window.getSelection){//ie11 10 9 ff safari
      obj.focus(); //解决ff不获取焦点无法定位问题
      var range = window.getSelection();//创建range
      range.selectAllChildren(obj);//range 选择obj下所有子内容
      range.collapseToEnd();//光标移至最后
    }
    else if (document.selection) {//ie10 9 8 7 6 5
      var range = document.selection.createRange();//创建选择对象
      range.moveToElementText(obj);//range定位到obj
      range.collapse(false);//光标移至最后
      range.select();
    }
  }
  handleFixClick(){
    this.moveEnd(this.$span.current);
  }
  componentDidMount(){
    //设置最小宽度避免输入后宽度跳动
    const spanWidth = window.getComputedStyle(this.$span.current).width;
    this.$span.current.style.minWidth=spanWidth;
  }
  componentWillReceiveProps(nextProps){
    if((nextProps.placeholder == this.props.placeholder)&&(nextProps.value == this.props.value)){
      return
    }
    this.setState({
      placeholder:nextProps.placeholder,
      value:nextProps.value
    })
  }
  render(){
    const {prefix,suffix,value} = this.props;
    const {placeholder} = this.state;
    return <div className={this.getStyle()}
                onClick={this.handleFixClick}>
                <span>{prefix}</span>
                <span className={style['free-in']}
                      contentEditable={true}
                      onBlur={this.handleBlur}
                      onInput={this.handleInput}
                      onFocus={this.handleFocus}
                      onClick={(e)=>{e.stopPropagation();}}
                      ref={this.$span}>&nbsp;{value||placeholder}</span>
                <span>{suffix}</span>
            </div>;
    }
}

export default InlineTag;
