import React, { Component } from "react";
import { connect } from "react-redux";
import style from "./index.less";
import ReactDom from "react-dom";
import logo from "../../common/images/logoa.png";
import setup from "../../common/images/setup.png";
import emergIcon from '../../common/images/emergency.png'
import {Notify} from '@commonComp';
import Emergency from '@containers/Emergency';
import {getAllHis} from '@store/async-actions/fetchModules.js';
import {timestampToTime,getCurrentDate} from '@utils/tools.js';
import {dragBox} from '@utils/drag';
import {CLEAR_COMSYMPTOMS} from '@store/types/mainSuit';
import ModeChange from './ModeChange'

class Banner extends Component {
  constructor(props){
    super(props)
    this.state = {
      mode: props.typeConfig,
      emergencyBox:false
    };
    this.showConfigModal = this.showConfigModal.bind(this);
    this.changeType = this.changeType.bind(this);
    this.confirmType = this.confirmType.bind(this);
    this.showHisModal = this.showHisModal.bind(this);
    this.handleHisClose = this.handleHisClose.bind(this);
  }

  showConfigModal(){
    this.setState({
      mode:this.props.typeConfig,
    });
    this.props.showConfigModal()
  }

  changeType(typeConfig){
    this.setState({
      mode:typeConfig
    });
  }

  confirmType(){
    const {typeConfig,confirmType,clearCommS,closeConfigModal,readMode} = this.props;
    const mode = this.state.mode;
    // 清空主诉常见症状
    clearCommS();
    if(mode==typeConfig&&typeConfig==readMode){
      closeConfigModal();
      return;
    }
    confirmType&&confirmType(mode);
    closeConfigModal()
  }
  showHisModal(){
    const {getAllRecord} = this.props;
    // 进入时默认展示当天的病例
    const item = {
      current:1,
      startDate:getCurrentDate(false)+' 00:00:00',
      endDate:getCurrentDate(false)+' 23:59:59'
    }
    getAllRecord&&getAllRecord(item);
    this.setState({
      emergencyBox:true,
    })
  }
  handleHisClose(){
    this.setState({
      emergencyBox:false,
    })
    dragBox('previewWrapper','previewStatic','del')    
  }
  render() {
    const {visible,ifShow,deptName, closeConfigModal,hasMain,hasCurrent,hasOther} = this.props;
    const {mode,emergencyBox} = this.state;
    const {showConfigModal, changeType, confirmType} = this;
    const domNode = document.getElementById('root');
    const disabled = !(hasMain||hasCurrent||hasOther);
    return (
      <div className={style["logo"]} >
        <img src={logo} />
        <span className={style["logo-name"]}>|&nbsp;&nbsp;智能辅助临床决策系统</span>
        <div className={style["buon"]}>
          {ifShow==1&&deptName=='急诊科'?<div className={style["buon1"]} onClick={this.showHisModal}>
                      <img className={`${style["st"]} ${style["his"]}`} src={emergIcon} />
                      本科室近期全部病历
                    </div>:''}
          <div className={style["buon1"]} onClick={showConfigModal}>
            <img className={style["st"]} src={setup} />
            设置
          </div>
        </div>
        {visible&& <ModeChange
          mode = {mode}
          hideBtn={disabled}
          closeConfigModal = {closeConfigModal}
          changeType = {changeType}
          confirmType = {confirmType}
        >
          </ModeChange>}
        {emergencyBox? ReactDom.createPortal(<React.Fragment> 
            <div className={style['modal']}>
              <div className={style['shade']} onClick={this.handleHisClose}></div>
              <Emergency show={emergencyBox} close={this.handleHisClose}/>
            </div>
          </React.Fragment>
          , domNode):''}
        
      </div>
    );
  }
}

const mapStateToProps = function(state){
  const {sysConfig} = state.homePage;
  const {message} = state.patInfo;
  return {
    ifShow:sysConfig.general_show,
    deptName:message.selfDeptName
  }
}

const mapDispatchToProps = function(dispatch){
  return {
    getAllRecord(item){
      dispatch(getAllHis(item));
    },
    clearCommS:()=>{//清除主诉常见症状
      dispatch({
        type: CLEAR_COMSYMPTOMS
      })
    },
  }
}
// export default Banner;
export default connect(mapStateToProps,mapDispatchToProps)(Banner);
